@@ -68,7 +68,7 @@ class GasOil(object):
         tag: str = "",
         krgendanchor: str = "sorg",
         fast: bool = False,
-        _sgl: float = None,  # Only to be used by GasWater.
+        _sgl: Optional[float] = None,  # Only to be used by GasWater.
     ) -> None:
         if h is None:
             h = 0.01
@@ -147,9 +147,7 @@ class GasOil(object):
         )
         sg_list.sort()
         self.table = pd.DataFrame(sg_list, columns=["SG"])
-        self.table["sgint"] = list(
-            map(int, list(map(round, self.table["SG"] * SWINTEGERS)))
-        )
+        self.table["sgint"] = list(map(round, self.table["SG"] * SWINTEGERS))
         self.table.drop_duplicates("sgint", inplace=True)
 
         # Now sg=1-sorg-swl might be accidentally dropped, so make sure we
@@ -190,6 +188,7 @@ class GasOil(object):
         self.table["SON"] = (self.table["SL"] - self.sorg - self.swl) / (
             1 - self.sorg - self.swl - self.sgro
         )
+        self.sgcomment: str = ""
         self.update_sgcomment_and_sorg()
         self.krgcomment = ""
         self.krogcomment = ""
@@ -999,7 +998,7 @@ class GasOil(object):
 
     def plotkrgkrog(
         self,
-        mpl_ax: None,
+        mpl_ax=None,
         color: str = "blue",
         alpha: float = 1.0,
         linewidth: int = 1,
