@@ -1,15 +1,17 @@
 """Object to represent GasWater, implemented as a Container
 object for one WaterOil and one GasOil object"""
 
-import logging
 from typing import Optional
 
 import pandas as pd
-from pyscal.utils.relperm import crosspoint
-from .wateroil import WaterOil
-from .gasoil import GasOil
 
-logger = logging.getLogger(__name__)
+from pyscal import getLogger_pyscal
+from pyscal.utils.relperm import crosspoint
+
+from .gasoil import GasOil
+from .wateroil import WaterOil
+
+logger = getLogger_pyscal(__name__)
 
 
 def is_documented_by(original):
@@ -31,6 +33,7 @@ class GasWater(object):
     Args:
         swirr: Irreducible water saturation for capillary pressure
         swl: First water saturation point in outputted tables.
+        sgl: Minimum gas saturation in a gas paleozone.
         swcr: Critical water saturation, water is immobile below this
         sgrw: Residual gas saturation after water flooding.
         sgcr: Critical gas saturation, gas is immobile below this
@@ -44,6 +47,7 @@ class GasWater(object):
         self,
         swirr: float = 0.0,
         swl: float = 0.0,
+        sgl: float = 0.0,
         swcr: float = 0.0,
         sgrw: float = 0.0,
         sgcr: float = 0.0,
@@ -68,10 +72,12 @@ class GasWater(object):
             tag=tag,
             fast=fast,
             _sgcr=sgcr,
+            _sgl=sgl,
         )
 
         self.sgcr: float = sgcr
         self.sgrw: float = sgrw
+        self.sgl: float = sgl
         # (remaining parameters are implemented as property functions)
 
         self.gasoil: GasOil = GasOil(
@@ -82,10 +88,10 @@ class GasWater(object):
             h=h,
             tag=tag,
             fast=fast,
+            _sgl=sgl,
         )
 
-        # Dummy oil curves, just to avoid objects
-        # being invalid.
+        # Dummy oil curves, just to avoid objects being invalid.
         self.wateroil.add_corey_oil()
         self.gasoil.add_corey_oil()
 
@@ -116,7 +122,7 @@ class GasWater(object):
 
         Args:
             nw: Corey parameter for water.
-            krwend: value of krw at 1 - sorw.
+            krwend: value of krw at 1 - sgcr.
             krwmax: maximal value at Sw=1. Default 1
         """
         self.wateroil.add_corey_water(nw, krwend, krwmax)
@@ -222,7 +228,7 @@ class GasWater(object):
         else:
             crosspoint_value = self.crosspoint()
             if crosspoint_value is not None:
-                crosspointcomment = "-- krw = krg @ sw=%1.5f\n" % crosspoint_value
+                crosspointcomment = f"-- krw = krg @ sw={crosspoint_value:1.5f}\n"
             else:
                 crosspointcomment = ""
         return self.wateroil.SWFN(
@@ -252,7 +258,7 @@ class GasWater(object):
         else:
             crosspoint_value = self.crosspoint()
             if crosspoint_value is not None:
-                crosspointcomment = "-- krw = krg @ sw=%1.5f\n" % crosspoint_value
+                crosspointcomment = f"-- krw = krg @ sw={crosspoint_value:1.5f}\n"
             else:
                 crosspointcomment = ""
         return self.gasoil.SGFN(
@@ -317,8 +323,8 @@ class GasWater(object):
 
         # pylint: disable=import-outside-toplevel
         # Lazy import of matplotlib for speed reasons.
-        import matplotlib.pyplot as plt
         import matplotlib
+        import matplotlib.pyplot as plt
 
         if mpl_ax is None:
             matplotlib.style.use("ggplot")
