@@ -68,8 +68,8 @@ class WaterOil(object):
         h: Optional[float] = None,
         tag: str = "",
         fast: bool = False,
-        _sgcr: float = None,
-        _sgl: float = None,
+        _sgcr: Optional[float] = None,
+        _sgl: Optional[float] = None,
     ) -> None:
         """Sets up the saturation range. Swirr is only relevant
         for the capillary pressure, not for relperm data.
@@ -91,6 +91,8 @@ class WaterOil(object):
         assert swcr < 1 - sorw
         assert swirr < 1 - sorw
 
+        self.swcomment: str = ""
+
         h_min = 1.0 / float(SWINTEGERS)
         if h < h_min:
             logger.warning(
@@ -147,9 +149,7 @@ class WaterOil(object):
 
         # Ensure that we do not have sw values that are too close
         # to each other, determined rougly by the distance 1/10000
-        self.table["swint"] = list(
-            map(int, list(map(round, self.table["SW"] * SWINTEGERS)))
-        )
+        self.table["swint"] = list(map(round, self.table["SW"] * SWINTEGERS))
         self.table.drop_duplicates("swint", inplace=True)
 
         # Now, sw=1-sorw might be accidentaly dropped, so make sure we
