@@ -4,6 +4,11 @@ place to have common fixtures, and avoiding flake8 complaints"""
 import logging
 
 import pytest
+from hypothesis import HealthCheck, settings
+
+settings.register_profile(
+    "ci", max_examples=250, deadline=None, suppress_health_check=[HealthCheck.too_slow]
+)
 
 
 @pytest.fixture
@@ -21,6 +26,7 @@ def default_loglevel():
 
 
 def pytest_addoption(parser):
+    """Add option(s) that can be used on the pytest command line"""
     parser.addoption(
         "--plot",
         action="store_true",
@@ -30,6 +36,7 @@ def pytest_addoption(parser):
 
 
 def pytest_collection_modifyitems(config, items):
+    """Act on options set on the command line"""
     if config.getoption("--plot"):
         # Do not skip tests when --plot is supplied on pytest command line
         return
