@@ -1,15 +1,12 @@
 """Test module for pyscal.*.add_fromtable()"""
 
-import pandas as pd
-import numpy as np
-
-import pytest
-
-from hypothesis import given, settings
 import hypothesis.strategies as st
+import numpy as np
+import pandas as pd
+import pytest
+from hypothesis import given
 
-from pyscal import WaterOil, GasOil, WaterOilGas
-
+from pyscal import GasOil, WaterOil, WaterOilGas
 from pyscal.utils.testing import check_table, float_df_checker
 
 
@@ -48,12 +45,25 @@ def test_go_fromtable_simple():
     assert np.isclose(sum(gasoil.table["PC"]), 11)  # Linearly increasing PCOG
     check_table(gasoil.table)
 
+    # Check that we can read the table also when the dataframe dtypes are strings
+    gasoil_str = GasOil(h=0.1)
+    gasoil_str.add_fromtable(
+        df1.astype(str),
+        sgcolname="SG",
+        krgcolname="KRG",
+        krogcolname="KROG",
+        pccolname="PC",
+    )
+    assert sum(gasoil_str.table["KRG"]) > 0
+    assert sum(gasoil_str.table["KROG"]) > 0
+    check_table(gasoil_str.table)
+
 
 def test_wo_fromtable_multiindex():
     """Test that we accept multiindex dataframes,
     (but a warning will be issued)"""
     # Test an example dataframe that easily gets sent in from ecl2df.satfunc:
-    df1 = pd.DataFrame(
+    dframe = pd.DataFrame(
         columns=["KEYWORD", "SATNUM", "SW", "KRW", "KROW", "PC"],
         data=[
             ["SWOF", 1, 0, 0, 1, 2],
@@ -63,11 +73,11 @@ def test_wo_fromtable_multiindex():
     ).set_index(["KEYWORD", "SATNUM"])
 
     # Check that we have a MultiIndex:
-    assert len(df1.index.names) == 2
+    assert len(dframe.index.names) == 2
 
     wateroil = WaterOil(h=0.1)
     wateroil.add_fromtable(
-        df1, swcolname="SW", krwcolname="KRW", krowcolname="KROW", pccolname="PC"
+        dframe, swcolname="SW", krwcolname="KRW", krowcolname="KROW", pccolname="PC"
     )
     assert "KRW" in wateroil.table.columns
     assert "KROW" in wateroil.table.columns
@@ -75,6 +85,32 @@ def test_wo_fromtable_multiindex():
     check_table(wateroil.table)
 
 
+def test_go_fromtable_multiindex():
+    """Test that we accept multiindex dataframes,
+    (but a warning will be issued)"""
+    # Test an example dataframe that easily gets sent in from ecl2df.satfunc:
+    dframe = pd.DataFrame(
+        columns=["KEYWORD", "SATNUM", "SG", "KRG", "KROG", "PC"],
+        data=[
+            ["SGOF", 1, 0, 0, 1, 0],
+            ["SGOF", 1, 0.5, 0.5, 0.5, 0],
+            ["SGOF", 1, 1, 1, 0, 0],
+        ],
+    ).set_index(["KEYWORD", "SATNUM"])
+
+    # Check that we have a MultiIndex:
+    assert len(dframe.index.names) == 2
+
+    gasoil = GasOil(h=0.1)
+    gasoil.add_fromtable(
+        dframe, sgcolname="SG", krgcolname="KRG", krogcolname="KROG", pccolname="PC"
+    )
+    assert "KRG" in gasoil.table.columns
+    assert "KROG" in gasoil.table.columns
+    assert "PC" in gasoil.table.columns
+    check_table(gasoil.table)
+
+
 def test_go_fromtable_problems():
     """Test loading from a table where there should be problems"""
     df1 = pd.DataFrame(
@@ -82,9 +118,10 @@ def test_go_fromtable_problems():
     )
     # Now sgcr and swl is wrong:
     gasoil = GasOil(h=0.1)
-    with pytest.raises(ValueError):
-        # Should say sg must start at zero.
-        gasoil.add_fromtable(df1, pccolname="PCOG")
+
+    with pytest.raises(ValueError, match="SBOGUS not found in dataframe"):
+        gasoil.add_fromtable(df1, sgcolname="SBOGUS")
+
     df2 = pd.DataFrame(
         columns=["SG", "KRG", "KROG", "PCOG"], data=[[0.0, 0, 1, 0], [0.9, 0.8, 0, 2]]
     )
@@ -108,25 +145,93 @@ def test_go_fromtable_problems():
     float_df_checker(gasoil.table, "SG", 1.0, "KRG", 0.8)
     float_df_checker(gasoil.table, "SG", 1.0, "KROG", 0.0)
     gasoil = GasOil(h=0.1, swl=0.1)
-    gasoil.add_fromtable(df2, krgcolname="KRG", krogcolname="KROG")
+    gasoil.add_fromtable(df2)
 
-    df3 = pd.DataFrame(
-        columns=["SG", "KRG", "KROG", "PCOG"], data=[[0, -0.01, 1, 0], [1, 1, 0, 0]]
-    )
-    gasoil = GasOil(h=0.1)
-    with pytest.raises(ValueError):
-        # Should say krg is negative
-        gasoil.add_fromtable(df3, krgcolname="KRG")
 
-    df4 = pd.DataFrame(
-        columns=["SG", "KRG", "KROG", "PCOG"],
-        data=[[0, 0, 1, 0], [1, 1.0000000001, 0, 0]],
-    )
+@pytest.mark.parametrize(
+    "dframe, exception, message",
+    [
+        (
+            pd.DataFrame(
+                columns=["SG", "KRG", "KROG", "PCOG"],
+                data=[[0, -0.01, 1, 0], [1, 1, 0, 0]],
+            ),
+            ValueError,
+            "krg is below 0 in incoming table",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KRG", "KROG", "PCOG"],
+                data=[[0, 0, 1, 0], [1, 1.0000000001, 0, 0]],
+            ),
+            ValueError,
+            "krg is above 1 in incoming table",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KRG", "KROG", "PCOG"],
+                data=[[0, 0, 0.5, 0], [1, 1, 0.9, 0]],
+            ),
+            ValueError,
+            "Incoming krog not decreasing",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KRG", "KROG", "PCOG"],
+                data=[[0, 0, 1, 0], [1, 1, -0.1, 0]],
+            ),
+            ValueError,
+            "krog is below 0 in incoming table",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KRG", "KROG", "PCOG"],
+                data=[[0.1, 0, 1, 0], [1, 1, 0.1, 0]],
+            ),
+            ValueError,
+            "sg must start at zero",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KRG", "KROG", "PCOG"],
+                data=[[0.0, 0, 1, 1], [1, 1, 0.1, 0]],
+            ),
+            ValueError,
+            "Incoming pc not increasing",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KRG", "KROG", "PCOG"],
+                data=[[0.0, 0, 1, 0], [1, 1, 0.1, np.inf]],
+            ),
+            ValueError,
+            # This one is from scipy/interpolate/_cubic.py
+            "must contain at least 2 elements",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KRG", "KROG", "PCOG"],
+                data=[[0.0, 0, 1, 0], [1, 1, 0.1, np.nan]],
+            ),
+            ValueError,
+            # This one is from scipy/interpolate/_cubic.py
+            "must contain at least 2 elements",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KRG", "KROG", "PCOG"],
+                data=[[0.0, 0, 1, 0], [0.5, 0.5, 0.5, 0.5], [1, 1, 0.1, np.inf]],
+            ),
+            ValueError,
+            "inf/nan in interpolated data",
+        ),
+    ],
+)
+def test_go_from_table_exceptions(dframe, exception, message):
+    """Test exceptions in loading tabular data for gasoil"""
     gasoil = GasOil(h=0.1)
-    with pytest.raises(ValueError):
-        # Should say krg is above 1.0
-        print(df4)
-        gasoil.add_fromtable(df4, krgcolname="KRG")
+    with pytest.raises(exception, match=message):
+        gasoil.add_fromtable(dframe)
 
 
 def test_gascondensate():
@@ -325,37 +430,51 @@ def test_wo_invalidcurves():
     assert wateroil.table["PC"].max() > pc3.iloc[1:]["PC"].max()
 
 
-def test_go_invalidcurves():
-    """Test  fromtable on invalid gasoil data"""
-    # Sw data not ordered:
-    krg1 = pd.DataFrame(columns=["SG", "KRG"], data=[[0.15, 0], [0.1, 1], [1, 1]])
+@pytest.mark.parametrize(
+    "dframe, match",
+    [
+        (pd.DataFrame(columns=["SG"], data=[[0.15], [1]]), "sg must start at zero"),
+        (
+            pd.DataFrame(columns=["SG", "KRG"], data=[[0.0, 0], [0.1, 0.4], [0.1, 1]]),
+            # error emitted by PchipInterpolator, not pyscal:
+            "`x` must be strictly increasing",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KRG"], data=[[0.0, 0], [0.4, 0.6], [0.6, 0.4], [1, 1]]
+            ),
+            "krg not increasing",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KROG"], data=[[0, 1], [0.4, 0.4], [0.6, 0.6], [1, 0]]
+            ),
+            "krog not decreasing",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "PCOG"], data=[[0, 1], [0.4, 0.4], [0.6, 0.6], [1, 0]]
+            ),
+            "Incoming pc not increasing",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KRG"], data=[[0, 1], [0.4, 0.6], [0.6, 0.4], [1, 1]]
+            ),
+            "Incoming krg not increasing",
+        ),
+        (
+            pd.DataFrame(
+                columns=["SG", "KROG"], data=[[0, 1.2], [0.4, 0.4], [0.6, 0.2], [1, 0]]
+            ),
+            "krog is above 1",
+        ),
+    ],
+)
+def test_go_invalidcurves(dframe, match):
     gasoil = GasOil(h=0.1)
-    with pytest.raises(ValueError):
-        # pchip-interpolator raises this error;
-        # x coordinates are not in increasing order
-        gasoil.add_fromtable(krg1, krgcolname="KRG")
-
-    krg2 = pd.DataFrame(
-        columns=["SG", "KRG"], data=[[0.15, 0], [0.4, 0.6], [0.6, 0.4], [1, 1]]
-    )
-    gasoil = GasOil(h=0.1)
-    with pytest.raises(ValueError):
-        # Should get notified that krg is not monotonous
-        gasoil.add_fromtable(krg2, krgcolname="KRG")
-    krog2 = pd.DataFrame(
-        columns=["SG", "KROG"], data=[[0.15, 1], [0.4, 0.4], [0.6, 0.6], [1, 0]]
-    )
-    gasoil = GasOil(h=0.1)
-    with pytest.raises(ValueError):
-        # Should get notified that krog is not monotonous
-        gasoil.add_fromtable(krog2, krogcolname="KROG")
-    pc2 = pd.DataFrame(
-        columns=["SG", "PC"], data=[[0.15, 1], [0.4, 0.4], [0.6, 0.6], [1, 0]]
-    )
-    gasoil = GasOil(h=0.1)
-    with pytest.raises(ValueError):
-        # Should get notified that pc is not monotonous
-        gasoil.add_fromtable(pc2, pccolname="PC")
+    with pytest.raises(ValueError, match=match):
+        gasoil.add_fromtable(dframe)
 
 
 def test_wo_fromtable_problems():
@@ -471,6 +590,7 @@ def test_wo_fromtable_problems():
     ],
 )
 def test_wo_from_table_exceptions(dframe, swl, exception, message):
+    """Test exceptions when loading wateroil data from tables"""
     wateroil = WaterOil(h=0.1, swl=swl)
     with pytest.raises(exception, match=message):
         wateroil.add_fromtable(dframe)
@@ -521,7 +641,6 @@ def test_fromtable_types():
         )
 
 
-@settings(deadline=2000)
 @given(st.floats(min_value=1e-5, max_value=1))
 def test_wo_fromtable_h(h):
     """Test making curves from tabular data with random stepsize h"""
