@@ -1,33 +1,36 @@
 """Test module for relperm interpolation support code"""
 
+import hypothesis.strategies as st
 import numpy as np
 import pandas as pd
-
+import pytest
+from hypothesis import given
 from matplotlib import pyplot as plt
 
-import pytest
-from hypothesis import given, settings
-import hypothesis.strategies as st
-
-
-from pyscal import WaterOil, GasOil
-from pyscal.utils.interpolation import (
-    normalize_nonlinpart_wo,
-    normalize_nonlinpart_go,
-    normalize_pc,
-    interpolate_wo,
-    interpolate_go,
-)
-from pyscal.utils.testing import check_table, float_df_checker, sat_table_str_ok
+from pyscal import GasOil, WaterOil
 from pyscal.constants import EPSILON as epsilon
+from pyscal.utils.interpolation import (
+    interpolate_go,
+    interpolate_wo,
+    normalize_nonlinpart_go,
+    normalize_nonlinpart_wo,
+    normalize_pc,
+)
+from pyscal.utils.testing import (
+    check_table,
+    float_df_checker,
+    sat_table_str_ok,
+    slow_hypothesis,
+)
 
 
-@settings(deadline=1000)
+@slow_hypothesis
 @given(
     st.floats(min_value=0, max_value=0.1),  # swl
     st.floats(min_value=0, max_value=0.0),  # dswcr
     st.floats(min_value=0, max_value=0.1),  # dswlhigh
     st.floats(min_value=0, max_value=0.3),  # sorw
+    st.floats(min_value=0, max_value=0.2),  # dsocrsorw
     st.floats(min_value=0.1, max_value=5),  # nw1
     st.floats(min_value=0.1, max_value=1),  # krwend1
     st.floats(min_value=0.1, max_value=5),  # now1
@@ -38,16 +41,32 @@ from pyscal.constants import EPSILON as epsilon
     st.floats(min_value=0.1, max_value=1),  # kroend2
 )
 def test_normalize_nonlinpart_wo_hypo(
-    swl, dswcr, dswlhigh, sorw, nw1, krwend1, now1, kroend1, nw2, krwend2, now2, kroend2
+    swl,
+    dswcr,
+    dswlhigh,
+    sorw,
+    dsocrsorw,
+    nw1,
+    krwend1,
+    now1,
+    kroend1,
+    nw2,
+    krwend2,
+    now2,
+    kroend2,
 ):
     # pylint: disable=too-many-arguments,too-many-locals
     """Test the normalization code in utils.
 
     In particular the fill_value argument to scipy has been tuned to
     fulfill this code"""
-    wo_low = WaterOil(swl=swl, swcr=swl + dswcr, sorw=sorw)
+    wo_low = WaterOil(swl=swl, swcr=swl + dswcr, sorw=sorw, socr=sorw + dsocrsorw)
+    sorw_high = max(sorw - 0.01, 0)
     wo_high = WaterOil(
-        swl=swl + dswlhigh, swcr=swl + dswlhigh + dswcr, sorw=max(sorw - 0.01, 0)
+        swl=swl + dswlhigh,
+        swcr=swl + dswlhigh + dswcr,
+        sorw=sorw_high,
+        socr=sorw_high + dsocrsorw,
     )
     wo_low.add_corey_water(nw=nw1, krwend=krwend1)
     wo_high.add_corey_water(nw=nw2, krwend=krwend2)
@@ -83,6 +102,12 @@ def test_normalize_pc(swirr, dswl):
     assert np.isclose(pc_fn(1), pc_min)
 
 
+def test_normalize_pc_wrongobject():
+    """Test error message when wrong object is provided"""
+    with pytest.raises(ValueError, match="Only WaterOil or GasOil"):
+        normalize_pc({})
+
+
 def test_normalize_emptypc():
     """Test that we can normalize both
     when pc is missing, and when it is all zero"""
@@ -219,12 +244,13 @@ def test_tag_preservation():
     sat_table_str_ok(interpolant1.SGOF())
 
 
-@settings(max_examples=40, deadline=5000)
+@slow_hypothesis
 @given(
     st.floats(min_value=0.01, max_value=0.1),  # swl
     st.floats(min_value=0, max_value=0.0),  # dswcr
     st.floats(min_value=0, max_value=0.1),  # dswlhigh
     st.floats(min_value=0, max_value=0.3),  # sorw
+    st.floats(min_value=0, max_value=0.3),  # dsocrsorw
     st.floats(min_value=1, max_value=5),  # nw_l
     st.floats(min_value=1, max_value=5),  # nw_h
     st.floats(min_value=1, max_value=5),  # now_l
@@ -239,6 +265,7 @@ def test_interpolate_wo(
     dswcr,
     dswlhigh,
     sorw,
+    dsocrsorw,
     nw_l,
     nw_h,
     now_l,
@@ -255,9 +282,13 @@ def test_interpolate_wo(
     this essentially checks that we can go continously between the
     two functions.
     """
-    wo_low = WaterOil(swl=swl, swcr=swl + dswcr, sorw=sorw)
+    wo_low = WaterOil(swl=swl, swcr=swl + dswcr, sorw=sorw, socr=sorw + dsocrsorw)
+    sorw_high = max(sorw - 0.01, 0)
     wo_high = WaterOil(
-        swl=swl + dswlhigh, swcr=swl + dswlhigh + dswcr, sorw=max(sorw - 0.01, 0)
+        swl=swl + dswlhigh,
+        swcr=swl + dswlhigh + dswcr,
+        sorw=max(sorw - 0.01, 0),
+        socr=sorw_high + dsocrsorw,
     )
     wo_low.add_corey_water(nw=nw_l, krwend=krwend_l)
     wo_high.add_corey_water(nw=nw_h, krwend=krwend_h)
@@ -276,6 +307,8 @@ def test_interpolate_wo(
     dists = [
         (wo_low.table - interp.table)[["KRW", "KROW"]].sum().sum() for interp in ips
     ]
+
+    # wo_low should be reproduced exactly:
     assert np.isclose(dists[0], 0)
 
     # Distance between high and the last interpolant
@@ -286,18 +319,16 @@ def test_interpolate_wo(
         (wo_low.table - interp.table)[["KRW", "KROW"]].sum().sum() for interp in ips
     ]
     print(
-        "Interpolation, mean: {}, min: {}, max: {}, std: {} ip-par-dist: {}".format(
-            np.mean(dists), min(dists), max(dists), np.std(np.diff(dists[1:])), ip_dist
-        )
+        f"Interpolation, mean: {np.mean(dists)}, min: {min(dists)}, "
+        f"max: {max(dists)}, std: {np.std(np.diff(dists[1:]))} ip-par-dist: {ip_dist}"
     )
-    assert np.isclose(dists[0], 0)  # Reproducing wo_low
     # All curves that are close in parameter t, should be close in sum().sum().
     # That means that diff of the distances should be similar,
     # that is the std.dev of the distances is low:
     ip_dist_std = np.std(np.diff(dists[1:]))  # This number depends on 'h' and 't' range
     # (avoiding the first which reproduces go_low
     if ip_dist_std > 1.0:  # Found by trial and error
-        print("ip_dist_std: {}".format(ip_dist_std))
+        print(f"ip_dist_std: {ip_dist_std}")
         print(dists)
 
         _, mpl_ax = plt.subplots()
@@ -312,7 +343,7 @@ def test_interpolate_wo(
     # trigger a discontinuity in the interpolants, which we don't want.
 
 
-@settings(max_examples=40, deadline=5000)
+@slow_hypothesis
 @given(
     st.floats(min_value=0.01, max_value=0.1),  # swl
     st.floats(min_value=0, max_value=0.0),  # dswcr
@@ -359,9 +390,8 @@ def test_interpolate_wo_pc(swl, dswcr, dswlhigh, sorw, a_l, a_h, b_l, b_h):
     # Distances between low and interpolants:
     dists = [(wo_low.table - interp.table)[["PC"]].sum().sum() for interp in ips]
     print(
-        "Interpolation, mean: {}, min: {}, max: {}, std: {} ip-par-dist: {}".format(
-            np.mean(dists), min(dists), max(dists), np.std(np.diff(dists[1:])), ip_dist
-        )
+        f"Interpolation, mean: {np.mean(dists)}, min: {min(dists)}, "
+        f"max: {max(dists)}, std: {np.std(np.diff(dists[1:]))} ip-par-dist: {ip_dist}"
     )
     assert np.isclose(dists[0], 0)  # Reproducing wo_low
     # All curves that are close in parameter t, should be close in sum().sum().
@@ -370,7 +400,7 @@ def test_interpolate_wo_pc(swl, dswcr, dswlhigh, sorw, a_l, a_h, b_l, b_h):
     ip_dist_std = np.std(np.diff(dists[1:]))  # This number depends on 'h' and 't' range
     # (avoiding the first which reproduces go_low
     if ip_dist_std > 1.0:  # Found by trial and error
-        print("ip_dist_std: {}".format(ip_dist_std))
+        print(f"ip_dist_std: {ip_dist_std}")
         print(dists)
         _, mpl_ax = plt.subplots()
         wo_low.plotpc(mpl_ax=mpl_ax, color="red", logyscale=True)
@@ -384,7 +414,7 @@ def test_interpolate_wo_pc(swl, dswcr, dswlhigh, sorw, a_l, a_h, b_l, b_h):
     # trigger a discontinuity in the interpolants, which we don't want.
 
 
-@settings(max_examples=40, deadline=1000)
+@slow_hypothesis
 @given(
     st.floats(min_value=0, max_value=0.1),  # swl
     st.floats(min_value=0, max_value=0.1),  # sgcr
@@ -646,7 +676,7 @@ def test_ip_go_kroend():
     assert float_df_checker(go_ip.table, "SG", 1 - 0.01 - 0.15, "KROG", 0)
 
 
-@settings(max_examples=50, deadline=5000)
+@slow_hypothesis
 @given(
     st.floats(min_value=0, max_value=0.1),  # swl
     st.floats(min_value=0, max_value=0.1),  # sgcr
@@ -724,9 +754,8 @@ def test_interpolate_go(
         (go_low.table - interp.table)[["KRG", "KROG"]].sum().sum() for interp in ips
     ]
     print(
-        "Interpolation, mean: {}, min: {}, max: {}, std: {} ip-par-dist: {}".format(
-            np.mean(dists), min(dists), max(dists), np.std(np.diff(dists[1:])), ip_dist
-        )
+        f"Interpolation, mean: {np.mean(dists)}, min: {min(dists)}, "
+        f"max: {max(dists)}, std: {np.std(np.diff(dists[1:]))} ip-par-dist: {ip_dist}"
     )
     assert np.isclose(dists[0], 0)  # Reproducing go_low
     # All curves that are close in parameter t, should be close in sum().sum().
@@ -738,7 +767,7 @@ def test_interpolate_go(
     # by how different the low and high is.
     # (avoiding the first which reproduces go_low
     if ip_dist_std > 1.0:  # number found from trial and error.
-        print("ip_dist_std: {}".format(ip_dist_std))
+        print(f"ip_dist_std: {ip_dist_std}")
         print(dists)
         _, mpl_ax = plt.subplots()
         go_low.plotkrgkrog(mpl_ax=mpl_ax, color="red")
@@ -837,6 +866,51 @@ def test_interpolations_wo_fromtable():
     assert np.isclose(wo_ip.estimate_sorw(), 0.15)
 
 
+def test_interpolations_wo_fromtable_socr():
+    """Test that socr is correctly handled through
+    both add_fromtable() and interpolation."""
+    base = pd.DataFrame(
+        columns=["SW", "KRW", "KROW"],
+        data=[
+            [0.0, 0.0, 1.0],
+            [0.1, 0.0, 1.0],
+            [0.2, 0.0, 1.0],  # swcr
+            [0.3, 0.1, 0.9],
+            [0.7, 0.3, 0.0],  # socr
+            [0.8, 0.8, 0.0],  # sorw
+            [0.9, 0.9, 0.0],
+            [1.0, 1.0, 0.0],
+        ],
+    )
+    opt = pd.DataFrame(
+        columns=["SW", "KRW", "KROW"],
+        data=[
+            [0.0, 0.0, 1.0],
+            [0.1, 0.0, 1.0],
+            [0.3, 0.0, 1.0],
+            [0.4, 0.1, 0.2],  # swcr
+            [0.9, 0.9, 0.0],  # sorw == socr
+            [0.95, 0.95, 0.0],
+            [1.0, 1.0, 0.0],
+        ],
+    )
+    wo_base = WaterOil(h=0.01)
+    wo_base.add_fromtable(base)
+    assert np.isclose(wo_base.estimate_swcr(), 0.2)
+    assert np.isclose(wo_base.estimate_sorw(), 0.2)
+    assert np.isclose(wo_base.estimate_socr(), 0.3)
+    wo_opt = WaterOil(h=0.01)
+    wo_opt.add_fromtable(opt)
+    assert np.isclose(wo_opt.estimate_swcr(), 0.3)
+    assert np.isclose(wo_opt.estimate_sorw(), 0.1)
+    assert np.isclose(wo_opt.estimate_socr(), 0.1)
+
+    wo_ip = interpolate_wo(wo_base, wo_opt, 0.5, h=0.01)
+    assert np.isclose(wo_ip.estimate_swcr(), 0.25)
+    assert np.isclose(wo_ip.estimate_sorw(), 0.15)
+    assert np.isclose(wo_ip.estimate_socr(), 0.2)
+
+
 @given(
     st.floats(min_value=0, max_value=0.1),  # sgro_low
     st.floats(min_value=0, max_value=0.1),  # sgro_high
@@ -882,3 +956,68 @@ def test_gasoil_gascond_fails():
 
     check_table(interpolate_go(gasoil, gascond, parameter=1.0 - epsilon).table)
     check_table(interpolate_go(gasoil, gascond, parameter=1.0).table)
+
+
+def test_endpointpitfalls_in_interpolation_socr():
+    """Demonstration of behaviour and pitfalls around endpoints (socr in particular)
+    when initializing objects through discretization (add_fromtable()) and how it will
+    affect interpolation.
+    """
+    wo_low = WaterOil(swl=0.1, sorw=0.12)
+    wo_low.add_LET_water(l=2, e=2, t=1)
+    wo_low.add_LET_oil(l=5, e=5, t=1)
+
+    assert wo_low.socr == wo_low.sorw  # By initialization
+
+    # The KROW values approach zero faster than KRW approaches 1,
+    # which makes the tabulated values indicate socr > sorw.
+    # This is correct behaviour given finite floating point accuracy.
+    assert wo_low.estimate_socr() > wo_low.estimate_sorw()  # difference is around 0.01
+    assert np.isclose(wo_low.estimate_sorw(), 0.12)  # correct estimate
+
+    # A not-so-extreme curve-set
+    wo_high = WaterOil(swl=0.1, sorw=0.12)
+    wo_high.add_LET_water(l=1, e=2, t=1)
+    wo_high.add_LET_oil(l=1, e=2, t=1)
+    assert wo_low.socr == wo_low.sorw
+    # No surprises:
+    assert np.isclose(wo_high.estimate_socr(), wo_high.estimate_sorw())
+
+    # If the original wo_low object is then reinitialized through its own
+    # discretization (e.g. via a SWOF file on disk and then back again, or via
+    # its table property and then add_fromtable()), the original knowledge that
+    # socr was defaulted and thus equal to sorw is lost and the best pyscal can
+    # do is to use the estimators
+    wo_low_dataframe = wo_low.table.copy()
+    wo_low_fromtable = WaterOil(wo_low_dataframe["SW"].min())
+    wo_low_fromtable.add_fromtable(wo_low_dataframe)
+    # The properties of the WaterOil object are now the estimated values.
+    assert wo_low_fromtable.socr > wo_low_fromtable.sorw
+
+    # Interpolation from the original low object or the discretized low object
+    # will be slightly different:
+    wo_ip_original = interpolate_wo(wo_low, wo_high, 0.5)
+    wo_ip_throughdiscretization = interpolate_wo(wo_low_fromtable, wo_high, 0.5)
+    # The right end of the curves will have slightly lower values due to
+    # the interpreteded socr for wo_ip_throughdiscretization:
+    assert (
+        wo_ip_original.table["KROW"].tail(20).sum()
+        > wo_ip_throughdiscretization.table["KROW"].tail(20).sum()
+    )
+    # But it can be circumvented by explicitly stating the endpoints when
+    # using add_fromtable()
+    wo_low_fromtable_fixed = WaterOil(wo_low_dataframe["SW"].min())
+    wo_low_fromtable_fixed.add_fromtable(wo_low_dataframe, sorw=0.12, socr=0.12)
+    wo_ip_throughdiscretization_fixed = interpolate_wo(
+        wo_low_fromtable_fixed, wo_high, 0.5
+    )
+    assert np.isclose(
+        wo_ip_original.table["KROW"].tail(20).sum(),
+        wo_ip_throughdiscretization_fixed.table["KROW"].tail(20).sum(),
+    )
+
+    # Plotting the minor discrepancy (zoom in to see the differences)
+    # _, mpl_ax = pyplot.subplots()
+    # wo_ip_original.plotkrwkrow(mpl_ax, color="green", alpha=0.6)
+    # wo_ip_throughdiscretization.plotkrwkrow(mpl_ax, color="red", alpha=0.6)
+    # pyplot.show()
