@@ -1,24 +1,22 @@
 """Test module for the WaterOil object"""
 import io
+import sys
 
-import pandas as pd
-import numpy as np
-
+import hypothesis.strategies as st
 import matplotlib
 import matplotlib.pyplot
-
+import numpy as np
+import pandas as pd
 import pytest
-from hypothesis import given, settings
-import hypothesis.strategies as st
+from hypothesis import given
 
 from pyscal import WaterOil
 from pyscal.constants import SWINTEGERS
-
 from pyscal.utils.testing import (
+    check_linear_sections,
     check_table,
     float_df_checker,
     sat_table_str_ok,
-    check_linear_sections,
 )
 
 
@@ -28,12 +26,11 @@ def check_endpoints(wateroil, krwend, krwmax, kroend):
     swtol = 1 / SWINTEGERS
 
     # Check endpoints for oil curve:
-    # krow at swcr should be kroend:
-    if wateroil.swcr > wateroil.swl + swtol:
-        assert float_df_checker(wateroil.table, "SON", 1.0, "KROW", kroend)
-    # krow at sorw should be zero:
-    assert float_df_checker(wateroil.table, "SON", 0.0, "KROW", 0.0)
+    assert float_df_checker(wateroil.table, "SW", wateroil.swl, "KROW", kroend)
+    assert float_df_checker(wateroil.table, "SON", 1, "KROW", kroend)
     assert np.isclose(wateroil.table["KROW"].max(), kroend)
+    assert float_df_checker(wateroil.table, "SON", 0.0, "KROW", 0.0)
+    assert float_df_checker(wateroil.table, "SW", 1 - wateroil.socr, "KROW", 0.0)
 
     # Check endpoints for water curve: (np.isclose is only reliable around 1)
     assert float_df_checker(wateroil.table, "SWN", 0.0, "KRW", 0.0)
@@ -58,7 +55,6 @@ def test_wateroil_tag(tag):
     sat_table_str_ok(wateroil.SWFN())
 
 
-@settings(deadline=1000)
 @given(st.floats(), st.floats())
 def test_wateroil_corey1(nw, now):
     """Test random corey parameters"""
@@ -79,7 +75,6 @@ def test_wateroil_corey1(nw, now):
     assert len(swofstr) > 100
 
 
-@settings(deadline=1000)
 @given(st.floats(), st.floats(), st.floats(), st.floats(), st.floats())
 def test_wateroil_let1(l, e, t, krwend, krwmax):
     """Test random LET parameters"""
@@ -99,21 +94,23 @@ def test_wateroil_let1(l, e, t, krwend, krwmax):
     assert len(swofstr) > 100
 
 
-@settings(deadline=500)
 @given(
     st.floats(min_value=0, max_value=0.4),
     st.floats(min_value=0, max_value=0.4),
     st.floats(min_value=0, max_value=0.4),
+    st.floats(min_value=0, max_value=0.1),
     st.floats(min_value=0.1, max_value=1),
     st.floats(min_value=0.1, max_value=1),
     st.floats(min_value=0.1, max_value=1),
-    st.floats(min_value=0.0001, max_value=1),
+    st.floats(min_value=0.001, max_value=1),
     st.booleans(),
 )
-def test_wateroil_krendmax(swl, swcr, sorw, kroend, krwend, krwmax, h, fast):
+def test_wateroil_krendmax(swl, swcr, sorw, socr_add, kroend, krwend, krwmax, h, fast):
     """Test endpoints for wateroil using hypothesis testing"""
     try:
-        wateroil = WaterOil(swl=swl, swcr=swcr, sorw=sorw, h=h, fast=fast)
+        wateroil = WaterOil(
+            swl=swl, swcr=swcr, socr=sorw + socr_add, sorw=sorw, h=h, fast=fast
+        )
     except AssertionError:
         return
     krwend = min(krwend, krwmax)
@@ -191,15 +188,21 @@ def test_linearsegments():
     check_linear_sections(wateroil)
 
 
-def test_plotting():
+@pytest.mark.skipif(sys.platform == "win32", reason="Plotting not stable on windows")
+def test_plotting(mocker):
     """Test that plotting code pass through (nothing displayed)"""
+    mocker.patch("matplotlib.pyplot.show", return_value=None)
     wateroil = WaterOil(swl=0.1, h=0.1)
     wateroil.add_corey_water()
     wateroil.add_corey_oil()
     wateroil.plotkrwkrow(mpl_ax=matplotlib.pyplot.subplots()[1])
+    wateroil.plotkrwkrow(logyscale=True, mpl_ax=matplotlib.pyplot.subplots()[1])
+    wateroil.plotkrwkrow(mpl_ax=None)
 
     wateroil.add_simple_J()
     wateroil.plotpc(mpl_ax=matplotlib.pyplot.subplots()[1])
+    wateroil.plotpc(mpl_ax=None)
+    wateroil.plotpc(logyscale=True)
 
 
 def test_wateroil_linear():
@@ -241,6 +244,7 @@ def test_comments():
     assert "swcr=0" in swfn
     assert "swl=0" in swfn
     assert "sorw=0" in swfn
+    assert "socr=0" not in swfn  # Only included when nonzero
     assert "nw=2" in swfn
     assert "krwend=1" in swfn
     assert "Corey" in swfn
@@ -258,6 +262,7 @@ def test_comments():
     assert "swcr=0" in swof
     assert "swl=0" in swof
     assert "sorw=0" in swof
+    assert "socr=0" not in swof  # Only included when nonzero
     assert "nw=2" in swof
     assert "now=2" in swof
     assert "krwend=1" in swof
@@ -269,6 +274,12 @@ def test_comments():
     assert "KROW" in swof
     assert "PC" in swof
 
+    paleo_wo = WaterOil(h=0.3, socr=0.1)
+    paleo_wo.add_corey_water()
+    paleo_wo.add_corey_oil()
+    assert "socr=0.1" in paleo_wo.SWFN()
+    assert "socr=0.1" in paleo_wo.SWOF()
+
 
 def test_nexus():
     """Test the Nexus export"""
@@ -276,17 +287,16 @@ def test_nexus():
     wateroil.add_corey_oil(now=10, kroend=0.5)
     wateroil.add_corey_water(nw=10, krwend=0.5)
     nexus_lines = wateroil.WOTABLE().splitlines()
-    non_comments = [
-        line for line in nexus_lines if not line.startswith("!") or not len(line)
-    ]
-    assert non_comments[0] == "WOTABLE"
-    assert non_comments[1] == "SW KRW KROW PC"
+    no_comments = [line for line in nexus_lines if not line.startswith("!") or not line]
+    assert no_comments[0] == "WOTABLE"
+    assert no_comments[1] == "SW KRW KROW PC"
     df = pd.read_table(
-        io.StringIO("\n".join(non_comments[2:])),
+        io.StringIO("\n".join(no_comments[2:])),
         engine="python",
         sep=r"\s+",
         header=None,
     )
+    # pylint: disable=no-member  # false positive on Pandas dataframe
     assert (df.values <= 1.0).all()
     assert (df.values >= 0.0).all()
 
